<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="23"/>
        <source>Lock Screen</source>
        <translation>Блокировка экрана</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="23"/>
        <source>Log Out</source>
        <translation>Выход из сеанса</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="23"/>
        <source>Suspend</source>
        <translation>Ждущий режим</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="23"/>
        <source>Reboot</source>
        <translation>Перезагрузка</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="23"/>
        <source>Shutdown</source>
        <translation>Выключение</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="42"/>
        <location filename="../main.cpp" line="50"/>
        <source>Pop-up with exit options for MX Fluxbox</source>
        <translation>Всплывающее окно с параметрами выхода для MX Fluxbox</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="43"/>
        <source>Display buttons in a vertical window</source>
        <translation>Отображать кнопки в вертикальном окне</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="44"/>
        <source>Display buttons in a horizontal window</source>
        <translation>Отображать кнопки в горизонтальном окне</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="45"/>
        <source>Timeout duration in seconds</source>
        <translation>Длительность таймаут в секундах:</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="46"/>
        <source>use -v, --vertical to display buttons vertically
use -h, --horizontal to display buttons horizontally.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Usage: exit-options [options]
</source>
        <translation>Использование: exit-options [параметры]
</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Options:</source>
        <translation>Опции:</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>  -h, --horizontal	 Option to display buttons horizontally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>  -v, --vertical	 Option to display buttons vertically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>  -t, --timeout &lt;sec&gt;	 Timeout duration in seconds
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="56"/>
        <source>The display orientation option used will be remembered and used the next time you start the app</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Alternativelly, set the option &apos;layout=horizontal&apos; or &apos;layout=vertical&apos; in ~/.config/MX-Linux/exit-options.conf</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>You can define custom icons by adding IconName=/path/iconame.ext in the exit-options.conf file. The names of the icons that you remap: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Other options that can be set in the exit-options.conf file: %1</source>
        <translation>Другие параметры, которые могут быть заданы в файле exit-options.conf: %1</translation>
    </message>
</context>
</TS>
